---
sd_hide_title: true
---

# SASKTRAN2 Performance Testing

::::{grid}
:reverse:
:gutter: 2 1 1 1
:margin: 4 4 1 1

:::{grid-item}
:columns: 4

```{image} ./_static/sasktran-dark.svg
:width: 250px
:class: sd-m-auto transparent-image only-light
:name: landing-page-logo-light
```

```{image} ./_static/sasktran-light.svg
:width: 250px
:class: sd-m-auto transparent-image only-dark
:name: landing-page-logo-dark
```
:::

:::{grid-item}
:columns: 8
:class: sd-fs-3

SASKTRAN2 Performance Tests

:::

::::

This sphinx book renders a collection of `.ipynb`

```{toctree}
:maxdepth: 4
:caption: External Validation

external_validation/coulsen
external_validation/korkin
external_validation/limb_vector_zawada_2021

```

```{toctree}
:maxdepth: 4
:caption: Internal Validation

internal_validation/layering

```


```{toctree}
:maxdepth: 4
:caption: Performance Testing

```
